---
paperswithcode_id: reclor
pretty_name: ReClor
---

### Contributions

Thanks to [@lewtun](https://github.com/lewtun), [@thomwolf](https://github.com/thomwolf), [@JetRunner](https://github.com/JetRunner), [@mariamabarham](https://github.com/mariamabarham), [@patrickvonplaten](https://github.com/patrickvonplaten), [@lhoestq](https://github.com/lhoestq) for adding this dataset.
